#
# spec file for package python-podman-compose
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%global src_name podman-compose
Name:           python-%{src_name}
Version:        1.2.0
Release:        1.3
Summary:        A script to run docker-compose using podman
License:        GPL-2.0-only
Group:          Development/Languages/Python
URL:            https://github.com/containers/%{src_name}
Source0:        %{src_name}-%{version}.tar.gz
Source1:        https://raw.githubusercontent.com/containers/%{src_name}/v%{version}/LICENSE
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module python-dotenv}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       podman
Requires:       python-PyYAML
Requires:       python-python-dotenv
Requires:       python-setuptools
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
Provides:       podman-compose = %{version}
Obsoletes:      podman-compose < %{version}
%python_subpackages

%description
An implementation of `docker-compose` with podman backend.
The main objective of this project is to be able to run `docker-compose.yml`
unmodified and rootless.  This project is aimed to provide drop-in replacement
for `docker-compose`, and it's very useful for certain cases because:

- can run rootless
- only depend on `podman` and Python3 and PyYAML
- no daemon, no setup
- can be used by developers to run single-machine containerized stacks using
  single familiar YAML file

%prep
%setup  -n %{src_name}-%{version}
cp %{SOURCE1} .

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/podman-compose
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_expand sed -i '1d' %{buildroot}%{$python_sitelib}/podman_compose.py

# %%check
# FIXME: we don't run upstream's tests, because those are currently only
# docker-compose files that are run via podman-compose to check the
# compatibility in a non-automated fashion.

%post
%python_install_alternative podman-compose

%postun
%python_uninstall_alternative podman-compose

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/*
%python_alternative %{_bindir}/%{src_name}

%changelog
* Sun Jun 30 2024 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 1.2.0:
  * Bug fixes
    ~ Fixed handling of --in-pod argument. Previously it was hard
    to provide false value to it.
    ~ podman-compose no longer creates pods when registering
    systemd unit.
    ~ Fixed warning RuntimeWarning: coroutine 'create_pods' was
    never awaited
    ~ Fixed error when setting up IPAM network with default driver.
    ~ Fixed support for having list and dictionary depends_on
    sections in related compose files.
    ~ Fixed logging of failed build message.
    ~ Fixed support for multiple entries in include section.
    ~ Fixed environment variable precedence order.
  * Changes
    ~ x-podman dictionary in container root has been migrated to
    x-podman.* fields in container root.
  * New features
    ~ Added support for --publish in podman-compose run.
    ~ Added support for Podman external root filesystem management
    (--rootfs option).
    ~ Added support for podman-compose images command.
    ~ Added support for env_file being configured via dictionaries.
    ~ Added support for enabling GPU access.
    ~ Added support for selinux in verbose mount specification.
    ~ Added support for additional_contexts section.
    ~ Added support for multi-line environment files.
    ~ Added support for passing contents of podman-compose.yml
    via stdin.
    ~ Added support for specifying the value for --in-pod setting
    in podman-compose.yml file.
    ~ Added support for environmental secrets.
* Fri Apr 19 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.1.0:
  * Release 1.1.0
  * Add release notes for v1.1.0
  * Use x- prefix for x-podman.mac_address
  * Use "service.build.ulimits" when present instead of
    "service.ulimits"
  * FIX issue
    https://github.com/containers/podman-compose/issues/704 -
    Windows fix sock not working.
- use obs_scm instead of PyPI tarball (that is broken again)
* Fri May  5 2023 Johannes Kastl <kastl@b1-systems.de>
- add sle15_python_module_pythons
* Thu Apr 13 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 1.0.6
  - no CHANGELOG available upstream or in PyPi
- add _service file
* Thu Jun 30 2022 Johannes Kastl <kastl@b1-systems.de>
- BuildRequire python-python-dotenv
* Wed Jun 29 2022 Johannes Kastl <kastl@b1-systems.de>
- major update to 1.0.3
  - no CHANGELOG available upstream or in PyPi
* Wed Jun 29 2022 Johannes Kastl <kastl@b1-systems.de>
- add Requires for python-setuptools,
  otherwise we run into 'ImportError: No module named pkg_resources'
* Wed Jun 29 2022 Johannes Kastl <kastl@b1-systems.de>
- add Provides and Obsoletes for podman-compose
* Wed Jun 29 2022 Johannes Kastl <kastl@b1-systems.de>
- fix builds on Tumbleweed, aka when building for more than one python,
  by using update-alternatives
* Thu Sep 10 2020 Frederic Crozat <fcrozat@suse.com>
- Add 0001-Add-support-for-devices-in-a-service.patch: add support
  for --devices.
* Thu Sep 10 2020 Frederic Crozat <fcrozat@suse.com>
- Add 0001-podman-volume-inspect-mountPoint-Mountpoint.patch:
  ensure new version of podman are supported.
* Tue Sep 24 2019 Dan Čermák <dcermak@suse.com>
- Initial package version of podman-compose
